Thread (2 messages) 2 messages, 2 authors, 2021-06-24

[PATCH] can/peak_pciefd: fix a potential issue of sending frames

STALE1926d LANDED

From: Stephane Grosjean <hidden>
Date: 2021-06-23 14:28:05
Subsystem: can network drivers, the rest · Maintainers: Marc Kleine-Budde, Vincent Mailhol, Linus Torvalds

Landed in mainline as b17233d385d0 on 2021-06-24.

Rather than just indicating that transmission can start, this patch
requires the explicit flushing of the network Tx queue when the driver is
informed by the device that it can transmit, next to its configuration.
In this way, if frames have already been written by the application, they
will actually be transmitted.

Signed-off-by: Stephane Grosjean <redacted>
---
 drivers/net/can/peak_canfd/peak_canfd.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/drivers/net/can/peak_canfd/peak_canfd.c b/drivers/net/can/peak_canfd/peak_canfd.c
index 00847cbaf7b6..d08718e98e11 100644
--- a/drivers/net/can/peak_canfd/peak_canfd.c
+++ b/drivers/net/can/peak_canfd/peak_canfd.c
@@ -351,8 +351,8 @@ static int pucan_handle_status(struct peak_canfd_priv *priv,
 				return err;
 		}
 
-		/* start network queue (echo_skb array is empty) */
-		netif_start_queue(ndev);
+		/* wake network queue up (echo_skb array is empty) */
+		netif_wake_queue(ndev);
 
 		return 0;
 	}
-- 
2.25.1
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help